@@ -1,12 +1,12 @@
 const DOCUMENTATION_OPTIONS = {
-    VERSION: 'v0.5.2',
+    VERSION: 'v0.7.0',
     LANGUAGE: 'en',
     COLLAPSE_INDEX: false,
     BUILDER: 'html',
     FILE_SUFFIX: '.html',
     LINK_SUFFIX: '.html',
     HAS_SOURCE: true,
-    SOURCELINK_SUFFIX: '.txt',
+    SOURCELINK_SUFFIX: '',
     NAVIGATION_WITH_KEYS: false,
     SHOW_SEARCH_SUMMARY: true,
     ENABLE_SEARCH_SHORTCUTS: true,
