@@ -1,6 +1,8 @@
 var classlibcamera_1_1MediaPipeline =
 [
+    [ "Entity", "structlibcamera_1_1MediaPipeline_1_1Entity.html", "structlibcamera_1_1MediaPipeline_1_1Entity" ],
     [ "configure", "classlibcamera_1_1MediaPipeline.html#a3aff5f63c49cf14155f2d3dba0110f9d", null ],
+    [ "entities", "classlibcamera_1_1MediaPipeline.html#a9e245dff1ed58686f4200ec16aa60fd8", null ],
     [ "init", "classlibcamera_1_1MediaPipeline.html#ae2c0b36e190c1eed389ab6e21e797ab8", null ],
     [ "initLinks", "classlibcamera_1_1MediaPipeline.html#afbacaccc50b41dd8406eaf20a9851b10", null ]
 ];
\ No newline at end of file
