@@ -2,6 +2,6 @@ var dir_c1abbc477dd89cdb70e22de0344d908c =
 [
     [ "debayer.h", "debayer_8h_source.html", null ],
     [ "debayer_cpu.h", "debayer__cpu_8h_source.html", null ],
-    [ "software_isp.cpp", "software__isp_8cpp.html", null ],
-    [ "swstats_cpu.h", "swstats__cpu_8h_source.html", null ]
+    [ "debayer_egl.h", "debayer__egl_8h_source.html", null ],
+    [ "software_isp.cpp", "software__isp_8cpp.html", null ]
 ];
\ No newline at end of file
