@@ -68,6 +68,8 @@ var namespacelibcamera =
     [ "DeviceEnumerator", "classlibcamera_1_1DeviceEnumerator.html", "classlibcamera_1_1DeviceEnumerator" ],
     [ "DmaBufAllocator", "classlibcamera_1_1DmaBufAllocator.html", "classlibcamera_1_1DmaBufAllocator" ],
     [ "DmaSyncer", "classlibcamera_1_1DmaSyncer.html", "classlibcamera_1_1DmaSyncer" ],
+    [ "eGLImage", "classlibcamera_1_1eGLImage.html", "classlibcamera_1_1eGLImage" ],
+    [ "eGL", "classlibcamera_1_1eGL.html", "classlibcamera_1_1eGL" ],
     [ "PixelFormatInfo", "classlibcamera_1_1PixelFormatInfo.html", "classlibcamera_1_1PixelFormatInfo" ],
     [ "GlobalConfiguration", "classlibcamera_1_1GlobalConfiguration.html", "classlibcamera_1_1GlobalConfiguration" ],
     [ "IPADataSerializer", "classlibcamera_1_1IPADataSerializer.html", null ],
@@ -93,9 +95,11 @@ var namespacelibcamera =
     [ "PubKey", "classlibcamera_1_1PubKey.html", "classlibcamera_1_1PubKey" ],
     [ "SharedMem", "classlibcamera_1_1SharedMem.html", "classlibcamera_1_1SharedMem" ],
     [ "SharedMemObject", "classlibcamera_1_1SharedMemObject.html", "classlibcamera_1_1SharedMemObject" ],
+    [ "Benchmark", "classlibcamera_1_1Benchmark.html", "classlibcamera_1_1Benchmark" ],
     [ "DebayerParams", "structlibcamera_1_1DebayerParams.html", "structlibcamera_1_1DebayerParams" ],
     [ "SoftwareIsp", "classlibcamera_1_1SoftwareIsp.html", "classlibcamera_1_1SoftwareIsp" ],
     [ "SwIspStats", "structlibcamera_1_1SwIspStats.html", "structlibcamera_1_1SwIspStats" ],
+    [ "SwStatsCpu", "classlibcamera_1_1SwStatsCpu.html", "classlibcamera_1_1SwStatsCpu" ],
     [ "V4L2Device", "classlibcamera_1_1V4L2Device.html", "classlibcamera_1_1V4L2Device" ],
     [ "V4L2PixelFormat", "classlibcamera_1_1V4L2PixelFormat.html", "classlibcamera_1_1V4L2PixelFormat" ],
     [ "V4L2Request", "classlibcamera_1_1V4L2Request.html", "classlibcamera_1_1V4L2Request" ],
@@ -129,7 +133,7 @@ var namespacelibcamera =
     [ "ThreadMain", "classlibcamera_1_1ThreadMain.html", "classlibcamera_1_1ThreadMain" ],
     [ "Debayer", "classlibcamera_1_1Debayer.html", "classlibcamera_1_1Debayer" ],
     [ "DebayerCpu", "classlibcamera_1_1DebayerCpu.html", "classlibcamera_1_1DebayerCpu" ],
-    [ "SwStatsCpu", "classlibcamera_1_1SwStatsCpu.html", "classlibcamera_1_1SwStatsCpu" ],
+    [ "DebayerEGL", "classlibcamera_1_1DebayerEGL.html", "classlibcamera_1_1DebayerEGL" ],
     [ "IPACameraSensorInfo", "structlibcamera_1_1IPACameraSensorInfo.html", "structlibcamera_1_1IPACameraSensorInfo" ],
     [ "IPABuffer", "structlibcamera_1_1IPABuffer.html", "structlibcamera_1_1IPABuffer" ],
     [ "IPASettings", "structlibcamera_1_1IPASettings.html", "structlibcamera_1_1IPASettings" ],
