@@ -15,6 +15,7 @@ var NAVTREEINDEX0 =
 "backtrace_8h_source.html":[8,0,1,0,0,0],
 "bayer__format_8h.html":[8,0,1,0,1,2],
 "bayer__format_8h_source.html":[8,0,1,0,1,2],
+"benchmark_8h_source.html":[8,0,1,0,1,1,0],
 "blc_8h.html":[8,0,2,0,0,0,4],
 "blc_8h_source.html":[8,0,2,0,0,0,4],
 "bound__method_8h.html":[8,0,1,0,0,1],
@@ -103,6 +104,14 @@ var NAVTREEINDEX0 =
 "classlibcamera_1_1BayerFormat.html#ac6c07588cb55b11984f379d893621dd6":[7,0,0,44,8],
 "classlibcamera_1_1BayerFormat.html#add4b672542165a208e519dd2c90a2f0a":[6,0,0,45,2],
 "classlibcamera_1_1BayerFormat.html#add4b672542165a208e519dd2c90a2f0a":[7,0,0,44,2],
+"classlibcamera_1_1Benchmark.html":[6,0,0,95],
+"classlibcamera_1_1Benchmark.html":[7,0,0,94],
+"classlibcamera_1_1Benchmark.html#a13b8dfd9bc6056c00ce51348b90e08c4":[6,0,0,95,1],
+"classlibcamera_1_1Benchmark.html#a13b8dfd9bc6056c00ce51348b90e08c4":[7,0,0,94,1],
+"classlibcamera_1_1Benchmark.html#ab257e55831c4311795a851e7433faa9c":[6,0,0,95,2],
+"classlibcamera_1_1Benchmark.html#ab257e55831c4311795a851e7433faa9c":[7,0,0,94,2],
+"classlibcamera_1_1Benchmark.html#ac441f2cc276e71c413314798ffbf9c91":[6,0,0,95,0],
+"classlibcamera_1_1Benchmark.html#ac441f2cc276e71c413314798ffbf9c91":[7,0,0,94,0],
 "classlibcamera_1_1ByteStreamBuffer.html":[6,0,0,46],
 "classlibcamera_1_1ByteStreamBuffer.html":[7,0,0,45],
 "classlibcamera_1_1ByteStreamBuffer.html#a15b0355a9b76b2cc9641ca228839000c":[6,0,0,46,2],
@@ -240,14 +249,5 @@ var NAVTREEINDEX0 =
 "classlibcamera_1_1CameraLens.html#a1bd1ec1324fb3fcb10096ff3ef088ff3":[6,0,0,48,5],
 "classlibcamera_1_1CameraLens.html#a1bd1ec1324fb3fcb10096ff3ef088ff3":[7,0,0,47,5],
 "classlibcamera_1_1CameraLens.html#a54123d701173d0f6d24626aa1d41b400":[6,0,0,48,6],
-"classlibcamera_1_1CameraLens.html#a54123d701173d0f6d24626aa1d41b400":[7,0,0,47,6],
-"classlibcamera_1_1CameraLens.html#a6291cfc11479b7842cfb209789f7c45c":[6,0,0,48,4],
-"classlibcamera_1_1CameraLens.html#a6291cfc11479b7842cfb209789f7c45c":[7,0,0,47,4],
-"classlibcamera_1_1CameraLens.html#a6610316d08ae4ba02ed942efbc0c7550":[6,0,0,48,3],
-"classlibcamera_1_1CameraLens.html#a6610316d08ae4ba02ed942efbc0c7550":[7,0,0,47,3],
-"classlibcamera_1_1CameraLens.html#ad998675c5a46796afe4a2c42a5458ec6":[6,0,0,48,1],
-"classlibcamera_1_1CameraLens.html#ad998675c5a46796afe4a2c42a5458ec6":[7,0,0,47,1],
-"classlibcamera_1_1CameraLens.html#ae47356daba26c29aabdf3fc2d4190023":[6,0,0,48,2],
-"classlibcamera_1_1CameraLens.html#ae47356daba26c29aabdf3fc2d4190023":[7,0,0,47,2],
-"classlibcamera_1_1CameraManager.html":[6,0,0,29]
+"classlibcamera_1_1CameraLens.html#a54123d701173d0f6d24626aa1d41b400":[7,0,0,47,6]
 };
