@@ -1,18 +1,75 @@
 var NAVTREEINDEX3 =
 {
-"classlibcamera_1_1DebayerCpu.html#a2ed0021813e3ca42fd945b7804f471ca":[7,0,0,127,7],
-"classlibcamera_1_1DebayerCpu.html#a5a2340eb70c69633826a050c8a2fcf61":[6,0,0,128,3],
-"classlibcamera_1_1DebayerCpu.html#a5a2340eb70c69633826a050c8a2fcf61":[7,0,0,127,3],
-"classlibcamera_1_1DebayerCpu.html#a7827ccae6f2570cd15dceb299319796a":[6,0,0,128,1],
-"classlibcamera_1_1DebayerCpu.html#a7827ccae6f2570cd15dceb299319796a":[7,0,0,127,1],
-"classlibcamera_1_1DebayerCpu.html#aa0a4baf692291dc0badf5087861063aa":[6,0,0,128,0],
-"classlibcamera_1_1DebayerCpu.html#aa0a4baf692291dc0badf5087861063aa":[7,0,0,127,0],
-"classlibcamera_1_1DebayerCpu.html#aee613f4b8a7d05cd0ccdb98b65009377":[6,0,0,128,2],
-"classlibcamera_1_1DebayerCpu.html#aee613f4b8a7d05cd0ccdb98b65009377":[7,0,0,127,2],
-"classlibcamera_1_1DebayerCpu.html#af235a1381203658b0b8b37f49696d3dd":[6,0,0,128,8],
-"classlibcamera_1_1DebayerCpu.html#af235a1381203658b0b8b37f49696d3dd":[7,0,0,127,8],
-"classlibcamera_1_1DebayerCpu.html#afc389be2603536de8b2b2c400b98bd3a":[6,0,0,128,4],
-"classlibcamera_1_1DebayerCpu.html#afc389be2603536de8b2b2c400b98bd3a":[7,0,0,127,4],
+"classlibcamera_1_1Debayer.html#a579fa6a49e82c6366dcaf7c54f6fbd93":[6,0,0,131,8],
+"classlibcamera_1_1Debayer.html#a579fa6a49e82c6366dcaf7c54f6fbd93":[7,0,0,130,8],
+"classlibcamera_1_1Debayer.html#a62a1b954b2c5ebf192fc58bea5c0ab71":[6,0,0,131,11],
+"classlibcamera_1_1Debayer.html#a62a1b954b2c5ebf192fc58bea5c0ab71":[7,0,0,130,11],
+"classlibcamera_1_1Debayer.html#a6a4144bbd58b39d72200e78e205ee95e":[6,0,0,131,21],
+"classlibcamera_1_1Debayer.html#a6a4144bbd58b39d72200e78e205ee95e":[7,0,0,130,21],
+"classlibcamera_1_1Debayer.html#a72e2733206944713bd20cd14a4fdde19":[6,0,0,131,5],
+"classlibcamera_1_1Debayer.html#a72e2733206944713bd20cd14a4fdde19":[7,0,0,130,5],
+"classlibcamera_1_1Debayer.html#a7bfb5cd1103513fe137f493c237fdfc4":[6,0,0,131,15],
+"classlibcamera_1_1Debayer.html#a7bfb5cd1103513fe137f493c237fdfc4":[7,0,0,130,15],
+"classlibcamera_1_1Debayer.html#a9b195704c31fbdb010909a5f6f1241ea":[6,0,0,131,16],
+"classlibcamera_1_1Debayer.html#a9b195704c31fbdb010909a5f6f1241ea":[7,0,0,130,16],
+"classlibcamera_1_1Debayer.html#aa200bbfcc23e038125ae1398c47fcf50":[6,0,0,131,10],
+"classlibcamera_1_1Debayer.html#aa200bbfcc23e038125ae1398c47fcf50":[7,0,0,130,10],
+"classlibcamera_1_1Debayer.html#ab5d8381042f97d2eb28eee4dd1ea9914":[6,0,0,131,20],
+"classlibcamera_1_1Debayer.html#ab5d8381042f97d2eb28eee4dd1ea9914":[7,0,0,130,20],
+"classlibcamera_1_1Debayer.html#ab9f83304b52dafe1358626a0da4a6a9d":[6,0,0,131,17],
+"classlibcamera_1_1Debayer.html#ab9f83304b52dafe1358626a0da4a6a9d":[7,0,0,130,17],
+"classlibcamera_1_1Debayer.html#ac847ab474a629c578e36e302b0f0d080":[6,0,0,131,4],
+"classlibcamera_1_1Debayer.html#ac847ab474a629c578e36e302b0f0d080":[7,0,0,130,4],
+"classlibcamera_1_1Debayer.html#adc1afbd1feb51f52eab80f332946738a":[6,0,0,131,14],
+"classlibcamera_1_1Debayer.html#adc1afbd1feb51f52eab80f332946738a":[7,0,0,130,14],
+"classlibcamera_1_1Debayer.html#ae0e4d6fa0ab2770f2b2adbf4a67e6b9c":[6,0,0,131,13],
+"classlibcamera_1_1Debayer.html#ae0e4d6fa0ab2770f2b2adbf4a67e6b9c":[7,0,0,130,13],
+"classlibcamera_1_1Debayer.html#af572391cee3293157385e9426f9c4693":[6,0,0,131,7],
+"classlibcamera_1_1Debayer.html#af572391cee3293157385e9426f9c4693":[7,0,0,130,7],
+"classlibcamera_1_1Debayer.html#aff446addc2471c07f1fde2782a871863":[6,0,0,131,2],
+"classlibcamera_1_1Debayer.html#aff446addc2471c07f1fde2782a871863":[7,0,0,130,2],
+"classlibcamera_1_1DebayerCpu.html":[6,0,0,132],
+"classlibcamera_1_1DebayerCpu.html":[7,0,0,131],
+"classlibcamera_1_1DebayerCpu.html#a0e83a0d14d3dc711ae7622c87ef8a655":[6,0,0,132,5],
+"classlibcamera_1_1DebayerCpu.html#a0e83a0d14d3dc711ae7622c87ef8a655":[7,0,0,131,5],
+"classlibcamera_1_1DebayerCpu.html#a1244659d82bd7411deaf58b28895de49":[6,0,0,132,4],
+"classlibcamera_1_1DebayerCpu.html#a1244659d82bd7411deaf58b28895de49":[7,0,0,131,4],
+"classlibcamera_1_1DebayerCpu.html#a2ed0021813e3ca42fd945b7804f471ca":[6,0,0,132,6],
+"classlibcamera_1_1DebayerCpu.html#a2ed0021813e3ca42fd945b7804f471ca":[7,0,0,131,6],
+"classlibcamera_1_1DebayerCpu.html#a7827ccae6f2570cd15dceb299319796a":[6,0,0,132,1],
+"classlibcamera_1_1DebayerCpu.html#a7827ccae6f2570cd15dceb299319796a":[7,0,0,131,1],
+"classlibcamera_1_1DebayerCpu.html#aa0a4baf692291dc0badf5087861063aa":[6,0,0,132,0],
+"classlibcamera_1_1DebayerCpu.html#aa0a4baf692291dc0badf5087861063aa":[7,0,0,131,0],
+"classlibcamera_1_1DebayerCpu.html#aee613f4b8a7d05cd0ccdb98b65009377":[6,0,0,132,2],
+"classlibcamera_1_1DebayerCpu.html#aee613f4b8a7d05cd0ccdb98b65009377":[7,0,0,131,2],
+"classlibcamera_1_1DebayerCpu.html#af235a1381203658b0b8b37f49696d3dd":[6,0,0,132,7],
+"classlibcamera_1_1DebayerCpu.html#af235a1381203658b0b8b37f49696d3dd":[7,0,0,131,7],
+"classlibcamera_1_1DebayerCpu.html#afc389be2603536de8b2b2c400b98bd3a":[6,0,0,132,3],
+"classlibcamera_1_1DebayerCpu.html#afc389be2603536de8b2b2c400b98bd3a":[7,0,0,131,3],
+"classlibcamera_1_1DebayerEGL.html":[6,0,0,133],
+"classlibcamera_1_1DebayerEGL.html":[7,0,0,132],
+"classlibcamera_1_1DebayerEGL.html#a3d4461ca13aec5745d172d09f2cc1dc7":[6,0,0,133,10],
+"classlibcamera_1_1DebayerEGL.html#a3d4461ca13aec5745d172d09f2cc1dc7":[7,0,0,132,10],
+"classlibcamera_1_1DebayerEGL.html#a4487adc49e1f06f7acdf9e0c04fde1e3":[6,0,0,133,6],
+"classlibcamera_1_1DebayerEGL.html#a4487adc49e1f06f7acdf9e0c04fde1e3":[7,0,0,132,6],
+"classlibcamera_1_1DebayerEGL.html#a50558bbdd5de1938afdd5a932f1271d0":[6,0,0,133,3],
+"classlibcamera_1_1DebayerEGL.html#a50558bbdd5de1938afdd5a932f1271d0":[7,0,0,132,3],
+"classlibcamera_1_1DebayerEGL.html#a64109f65b6c7f46fbf651876e212c72c":[6,0,0,133,2],
+"classlibcamera_1_1DebayerEGL.html#a64109f65b6c7f46fbf651876e212c72c":[7,0,0,132,2],
+"classlibcamera_1_1DebayerEGL.html#a8d8039fbf33c8edb649ac10c8fdfcf53":[6,0,0,133,4],
+"classlibcamera_1_1DebayerEGL.html#a8d8039fbf33c8edb649ac10c8fdfcf53":[7,0,0,132,4],
+"classlibcamera_1_1DebayerEGL.html#a98e6abdd93bd7f0915a5c86ab4faed9e":[6,0,0,133,9],
+"classlibcamera_1_1DebayerEGL.html#a98e6abdd93bd7f0915a5c86ab4faed9e":[7,0,0,132,9],
+"classlibcamera_1_1DebayerEGL.html#ab2987e00c71a7ddd5c139e3748859b9d":[6,0,0,133,5],
+"classlibcamera_1_1DebayerEGL.html#ab2987e00c71a7ddd5c139e3748859b9d":[7,0,0,132,5],
+"classlibcamera_1_1DebayerEGL.html#ac56229c61bc70c728f13a60c6ef9567d":[6,0,0,133,8],
+"classlibcamera_1_1DebayerEGL.html#ac56229c61bc70c728f13a60c6ef9567d":[7,0,0,132,8],
+"classlibcamera_1_1DebayerEGL.html#ac9673cfc76465344e310d13b2993c728":[6,0,0,133,0],
+"classlibcamera_1_1DebayerEGL.html#ac9673cfc76465344e310d13b2993c728":[7,0,0,132,0],
+"classlibcamera_1_1DebayerEGL.html#adbbfdd0a7f34be2093fd8b7ff0f4aec6":[6,0,0,133,7],
+"classlibcamera_1_1DebayerEGL.html#adbbfdd0a7f34be2093fd8b7ff0f4aec6":[7,0,0,132,7],
+"classlibcamera_1_1DebayerEGL.html#af4e80df333a804c4d7e7f36c6e89f702":[6,0,0,133,1],
+"classlibcamera_1_1DebayerEGL.html#af4e80df333a804c4d7e7f36c6e89f702":[7,0,0,132,1],
 "classlibcamera_1_1DebugMetadata.html":[6,0,0,62],
 "classlibcamera_1_1DebugMetadata.html":[7,0,0,61],
 "classlibcamera_1_1DebugMetadata.html#a1f327440ab91a6f6560eb2fd8891b790":[6,0,0,62,2],
@@ -59,10 +116,12 @@ var NAVTREEINDEX3 =
 "classlibcamera_1_1DeviceMatch.html":[7,0,0,63],
 "classlibcamera_1_1DeviceMatch.html#a118bb7d1b27680fe22b4b339ae8c5207":[6,0,0,64,0],
 "classlibcamera_1_1DeviceMatch.html#a118bb7d1b27680fe22b4b339ae8c5207":[7,0,0,63,0],
+"classlibcamera_1_1DeviceMatch.html#ac8b8c49aae6ede41d4b7fc6c488374e8":[6,0,0,64,2],
+"classlibcamera_1_1DeviceMatch.html#ac8b8c49aae6ede41d4b7fc6c488374e8":[7,0,0,63,2],
 "classlibcamera_1_1DeviceMatch.html#acf0e970d41842da73e1ee25bfb24de3a":[6,0,0,64,1],
 "classlibcamera_1_1DeviceMatch.html#acf0e970d41842da73e1ee25bfb24de3a":[7,0,0,63,1],
-"classlibcamera_1_1DeviceMatch.html#ae9923a86604c13eb08c0273b95d0a923":[6,0,0,64,2],
-"classlibcamera_1_1DeviceMatch.html#ae9923a86604c13eb08c0273b95d0a923":[7,0,0,63,2],
+"classlibcamera_1_1DeviceMatch.html#ae9923a86604c13eb08c0273b95d0a923":[6,0,0,64,3],
+"classlibcamera_1_1DeviceMatch.html#ae9923a86604c13eb08c0273b95d0a923":[7,0,0,63,3],
 "classlibcamera_1_1DmaBufAllocator.html":[6,0,0,66],
 "classlibcamera_1_1DmaBufAllocator.html":[7,0,0,65],
 "classlibcamera_1_1DmaBufAllocator.html#a2f1d955f4bff2bd4929fd895b7f0eae5":[6,0,0,66,6],
@@ -190,64 +249,5 @@ var NAVTREEINDEX3 =
 "classlibcamera_1_1EventNotifier.html#a48ecc3b2072be4029d6a60a987c4122a":[6,0,0,7,2],
 "classlibcamera_1_1EventNotifier.html#a48ecc3b2072be4029d6a60a987c4122a":[7,0,0,6,2],
 "classlibcamera_1_1EventNotifier.html#a75a222d261786d5866d7f69406630061":[6,0,0,7,5],
-"classlibcamera_1_1EventNotifier.html#a75a222d261786d5866d7f69406630061":[7,0,0,6,5],
-"classlibcamera_1_1EventNotifier.html#a83550c524a9bcc0ea582e876ca43c04d":[6,0,0,7,4],
-"classlibcamera_1_1EventNotifier.html#a83550c524a9bcc0ea582e876ca43c04d":[7,0,0,6,4],
-"classlibcamera_1_1EventNotifier.html#ac8abf83fcaebd9ec6595e9ea7f426c8e":[6,0,0,7,1],
-"classlibcamera_1_1EventNotifier.html#ac8abf83fcaebd9ec6595e9ea7f426c8e":[7,0,0,6,1],
-"classlibcamera_1_1EventNotifier.html#adceea4fbe37e9a3833dce6e258e35238":[6,0,0,7,0],
-"classlibcamera_1_1EventNotifier.html#adceea4fbe37e9a3833dce6e258e35238":[7,0,0,6,0],
-"classlibcamera_1_1EventNotifier.html#adceea4fbe37e9a3833dce6e258e35238a0def601bcb4442f07c3f772875fc8da4":[6,0,0,7,0,2],
-"classlibcamera_1_1EventNotifier.html#adceea4fbe37e9a3833dce6e258e35238a0def601bcb4442f07c3f772875fc8da4":[7,0,0,6,0,2],
-"classlibcamera_1_1EventNotifier.html#adceea4fbe37e9a3833dce6e258e35238a3291c8605f14dd5f7e37b1b45dca76e9":[6,0,0,7,0,1],
-"classlibcamera_1_1EventNotifier.html#adceea4fbe37e9a3833dce6e258e35238a3291c8605f14dd5f7e37b1b45dca76e9":[7,0,0,6,0,1],
-"classlibcamera_1_1EventNotifier.html#adceea4fbe37e9a3833dce6e258e35238acb9c83f52b00cc7cb91bb6a5235b91f6":[6,0,0,7,0,0],
-"classlibcamera_1_1EventNotifier.html#adceea4fbe37e9a3833dce6e258e35238acb9c83f52b00cc7cb91bb6a5235b91f6":[7,0,0,6,0,0],
-"classlibcamera_1_1EventNotifier.html#afd2af0fa47b553e9333f9feffb08449a":[6,0,0,7,7],
-"classlibcamera_1_1EventNotifier.html#afd2af0fa47b553e9333f9feffb08449a":[7,0,0,6,7],
-"classlibcamera_1_1Extensible.html":[6,0,0,4],
-"classlibcamera_1_1Extensible.html":[7,0,0,3],
-"classlibcamera_1_1Extensible.html#a524dff9d63a486fc4cfc2d0d1ce07711":[6,0,0,4,3],
-"classlibcamera_1_1Extensible.html#a524dff9d63a486fc4cfc2d0d1ce07711":[7,0,0,3,3],
-"classlibcamera_1_1Extensible.html#a7a31dab4cfefc741263bd8407bd29b6f":[6,0,0,4,2],
-"classlibcamera_1_1Extensible.html#a7a31dab4cfefc741263bd8407bd29b6f":[7,0,0,3,2],
-"classlibcamera_1_1Extensible.html#afb1c6e39d8fe4fbeab1cbbbe65517f4c":[6,0,0,4,1],
-"classlibcamera_1_1Extensible.html#afb1c6e39d8fe4fbeab1cbbbe65517f4c":[7,0,0,3,1],
-"classlibcamera_1_1Extensible_1_1Private.html":[6,0,0,4,0],
-"classlibcamera_1_1Extensible_1_1Private.html":[7,0,0,3,0],
-"classlibcamera_1_1Extensible_1_1Private.html#a58af2c3e5a3ff3301df0a10ea282c766":[6,0,0,4,0,0],
-"classlibcamera_1_1Extensible_1_1Private.html#a58af2c3e5a3ff3301df0a10ea282c766":[7,0,0,3,0,0],
-"classlibcamera_1_1Fence.html":[6,0,0,37],
-"classlibcamera_1_1Fence.html":[7,0,0,36],
-"classlibcamera_1_1Fence.html#a1b435a69df48ed28e888ef82f1a2d15a":[6,0,0,37,2],
-"classlibcamera_1_1Fence.html#a1b435a69df48ed28e888ef82f1a2d15a":[7,0,0,36,2],
-"classlibcamera_1_1Fence.html#a5beebc2b3cd811bdea441b3d848e3419":[6,0,0,37,3],
-"classlibcamera_1_1Fence.html#a5beebc2b3cd811bdea441b3d848e3419":[7,0,0,36,3],
-"classlibcamera_1_1Fence.html#aaa3009c674cee1c2172e6d481f4540b8":[6,0,0,37,1],
-"classlibcamera_1_1Fence.html#aaa3009c674cee1c2172e6d481f4540b8":[7,0,0,36,1],
-"classlibcamera_1_1Fence.html#ab84dac1ce57f0370012d6b278a99325a":[6,0,0,37,0],
-"classlibcamera_1_1Fence.html#ab84dac1ce57f0370012d6b278a99325a":[7,0,0,36,0],
-"classlibcamera_1_1File.html":[6,0,0,8],
-"classlibcamera_1_1File.html":[7,0,0,7],
-"classlibcamera_1_1File.html#a128efbbcacb7cdaa1986ffc943e89ae0":[6,0,0,8,2],
-"classlibcamera_1_1File.html#a128efbbcacb7cdaa1986ffc943e89ae0":[7,0,0,7,2],
-"classlibcamera_1_1File.html#a128efbbcacb7cdaa1986ffc943e89ae0a44f0e1a448f14b3cfcae67338bdc04bb":[6,0,0,8,2,0],
-"classlibcamera_1_1File.html#a128efbbcacb7cdaa1986ffc943e89ae0a44f0e1a448f14b3cfcae67338bdc04bb":[7,0,0,7,2,0],
-"classlibcamera_1_1File.html#a128efbbcacb7cdaa1986ffc943e89ae0a47f9082fc380ca62d531096aa1d110f1":[6,0,0,8,2,1],
-"classlibcamera_1_1File.html#a128efbbcacb7cdaa1986ffc943e89ae0a47f9082fc380ca62d531096aa1d110f1":[7,0,0,7,2,1],
-"classlibcamera_1_1File.html#a17a868b3e07508e37463acbbd525e881":[6,0,0,8,8],
-"classlibcamera_1_1File.html#a17a868b3e07508e37463acbbd525e881":[7,0,0,7,8],
-"classlibcamera_1_1File.html#a387e2f92eb36a45aad031915ca90471a":[6,0,0,8,10],
-"classlibcamera_1_1File.html#a387e2f92eb36a45aad031915ca90471a":[7,0,0,7,10],
-"classlibcamera_1_1File.html#a41891c0fb18b11268b9367df43f99532":[6,0,0,8,9],
-"classlibcamera_1_1File.html#a41891c0fb18b11268b9367df43f99532":[7,0,0,7,9],
-"classlibcamera_1_1File.html#a51d5e31e1583c024674392b721fe81d7":[6,0,0,8,13],
-"classlibcamera_1_1File.html#a51d5e31e1583c024674392b721fe81d7":[7,0,0,7,13],
-"classlibcamera_1_1File.html#a596bea491fd1306082e462842559c929":[6,0,0,8,21],
-"classlibcamera_1_1File.html#a596bea491fd1306082e462842559c929":[7,0,0,7,21],
-"classlibcamera_1_1File.html#a62ad081ef9f239b476815bf855de08d7":[6,0,0,8,7],
-"classlibcamera_1_1File.html#a62ad081ef9f239b476815bf855de08d7":[7,0,0,7,7],
-"classlibcamera_1_1File.html#a6df7f0036263a0a04610e586e9e604cb":[6,0,0,8,3],
-"classlibcamera_1_1File.html#a6df7f0036263a0a04610e586e9e604cb":[7,0,0,7,3],
-"classlibcamera_1_1File.html#a6df7f0036263a0a04610e586e9e604cba131fb182a881796e7606ed6da27f1197":[6,0,0,8,3,1]
+"classlibcamera_1_1EventNotifier.html#a75a222d261786d5866d7f69406630061":[7,0,0,6,5]
 };
