@@ -10,7 +10,7 @@ var searchData=
   ['activeareasize_7',['activeAreaSize',['../structlibcamera_1_1IPACameraSensorInfo.html#ab9bcb46cefbc066407cc2b452968aeb4',1,'libcamera::IPACameraSensorInfo']]],
   ['activeformat_8',['ActiveFormat',['../classlibcamera_1_1V4L2Subdevice.html#a9e0329816bbda2b6745b5c72233d5091afe2c4e6d1558ed7d5b163f1b10920ba3',1,'libcamera::V4L2Subdevice']]],
   ['activestate_9',['activeState',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAContext.html#ac8325de1b3acbebb7bf813ebf89cc76b',1,'libcamera::ipa::ipu3::IPAContext']]],
-  ['add_10',['add',['../classlibcamera_1_1DeviceMatch.html#acf0e970d41842da73e1ee25bfb24de3a',1,'libcamera::DeviceMatch']]],
+  ['add_10',['add',['../classlibcamera_1_1DeviceMatch.html#acf0e970d41842da73e1ee25bfb24de3a',1,'libcamera::DeviceMatch::add(const std::string &amp;entity)'],['../classlibcamera_1_1DeviceMatch.html#ac8b8c49aae6ede41d4b7fc6c488374e8',1,'libcamera::DeviceMatch::add(std::regex entity)']]],
   ['addbuffer_11',['addBuffer',['../classlibcamera_1_1Request.html#a5d15a702b3d791edcab102ecd68a9082',1,'libcamera::Request']]],
   ['addconfiguration_12',['addConfiguration',['../classlibcamera_1_1CameraConfiguration.html#aa06a84e7e133269f226a9b2016f08401',1,'libcamera::CameraConfiguration']]],
   ['adddevice_13',['addDevice',['../classlibcamera_1_1DeviceEnumerator.html#a1e618229382268ba6ef0a559afaa51cf',1,'libcamera::DeviceEnumerator']]],
