@@ -6,7 +6,7 @@ var indexSectionsWithContent =
   3: "abcdefghilmoprstuvy",
   4: "_abcdefghijklmnopqrstuvwxyz~",
   5: "abcdefghiklmnopqrstuvwxy",
-  6: "bcdfhilmoprst",
+  6: "bcdfhimoprst",
   7: "abcdefhilmnoprstwy",
   8: "abcdefghiklmnoprstuvw",
   9: "o",
