@@ -6,5 +6,6 @@ var searchData=
   ['wdrmodenamevaluemap_3',['WdrModeNameValueMap',['../namespacelibcamera_1_1controls.html#a3cb3397419a95a23845649199c117b3a',1,'libcamera::controls']]],
   ['wdrmodevalues_4',['WdrModeValues',['../namespacelibcamera_1_1controls.html#af5c53432fca9d7b03a43af1fc856c4bb',1,'libcamera::controls']]],
   ['wdrstrength_5',['WdrStrength',['../namespacelibcamera_1_1controls.html#a47b50186d20fa309194bb8d311d11bab',1,'libcamera::controls']]],
-  ['width_6',['width',['../classlibcamera_1_1Size.html#a0063ea1917eeaa0b34a4cf21507dea25',1,'libcamera::Size::width'],['../classlibcamera_1_1Rectangle.html#a5f8d8b47966e5212e08ee1770a07a550',1,'libcamera::Rectangle::width']]]
+  ['width_6',['width',['../classlibcamera_1_1Size.html#a0063ea1917eeaa0b34a4cf21507dea25',1,'libcamera::Size::width'],['../classlibcamera_1_1Rectangle.html#a5f8d8b47966e5212e08ee1770a07a550',1,'libcamera::Rectangle::width']]],
+  ['width_5f_7',['width_',['../classlibcamera_1_1eGLImage.html#aff91b75ac2b90b0faea5be583ffd9710',1,'libcamera::eGLImage']]]
 ];
